# Gitlab Release Notes Generator

Generate a changelog listing all merged requests since the last release of the repository.

## Do it online: 
[![Heroku](https://pyheroku-badge.herokuapp.com/?app=gitlab-release-notes)](https://gitlab-release-notes.herokuapp.com/)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/vuillaut/GitlabReleaseNotesGenerator/HEAD?labpath=generate.ipynb)
